Learn R Programming

MACP (version 0.1.0)

EliminateCpxRedundance: Hierarchical Clustering of Modules

Description

This function reduces redundancy in the reference complexes by first computing the overlap of two complexes via Jaccard index, followed by merging overlapping complexes with user-defined threshold (here is 0.2).

Usage

EliminateCpxRedundance(
  rawCpx,
  custom_bg = NULL,
  sim_method = "euclidean",
  linkage = "average",
  h = 0.2
)

Value

List of unique complexes.

Arguments

rawCpx

A list containing protein complexes

custom_bg

Vector of proteins names to use as a background. If given, refcpx will be first mapped to the background proteisn, followed by removing redundancy in the refcpx.

sim_method

c(euclidean", "maximum", "manhattan", "canberra", "binary", or "minkowski"); Default is euclidean

linkage

c("average", "ward", "single", "complete", "mcquitty", "median", "centroid"); Default is average.

h

numeric scalar or vector with heights where the tree should be cut; Defaults to 0.2

Author

Matineh Rahmatbakhsh

Details

EliminateCpxRedundance

Examples

Run this code
# predicted interactions
pred_ppi <- read.table(
system.file("extdata/ppi_input_ClusterONE.txt", package = "MACP"),
header = FALSE)
# get all the proteins in the predicted network
custom_bg <- union(pred_ppi$V1, pred_ppi$V2)
# reference complexes
data("refcpx")
# reduce redundancy in reference complexes
filt_cpx <- EliminateCpxRedundance(refcpx,
custom_bg,
sim_method = "euclidean",
linkage="average",
h = 0.2)

Run the code above in your browser using DataLab